#!/bin/bash

dotfiles=(vimrc
          zshrc
          pbuilderrc
          quiltrc
          dput.cf
          conkyrc
          gitconfig
          pastebinit.xml
          xchat2/xchat.conf xchat2/servlist_.conf xchat2/notify.conf xchat2/chanserv-mod.py 
          VirtualBox/VirtualBox.xml
          mutt/muttrc mutt/mutt.sh mutt/signature mutt/colors mutt/gpg irssi/config
          )
files=(pbuilder/hooks
       pbuilder/scripts
       )
emptydotdirs=()
emptydirs=(pbuilder/result)
repos=(google-talkplugin.list)
reposdeb=()
packages=(geany
          google-talkplugin
          filezilla
          samba
          gimp
          inkscape
          cheese
          chromium-browser
          xchat
          eatmydata #to use pbuilder quickly
          build-essential
          debhelper
          ubuntu-dev-tools
          pbuilder
          lintian
          gnupg2 gnupg-agent
          )

personal () {
    echo ""
}

# This function create files, directories and symlinks, as needed
files () {
    echo "Creating empty dirs..."
    for dir in ${emptydotdirs[@]}; do
        if [ ! -a $HOME/.${dir} ] ; then
            mkdir -pv $HOME/.${dir}
        fi
    done
    for dir in ${emptydirs[@]}; do
        if [ ! -a $HOME/${dir} ] ; then
            mkdir -pv $HOME/${dir}
        fi
    done

    echo "Creating symlinks..."
    for file in ${dotfiles[@]}; do
        # for files
        if [ -f $HOME/settings/${file} ] ; then
            if [ -a $HOME/.${file} ] ; then
                rm $HOME/.${file}
            fi
            if (echo ${file} | grep -q '/' && [ ! -d $HOME/.$(echo ${file} | cut -f 1 -d '/') ]) ; then
                mkdir $HOME/.$(echo ${file} | cut -f 1 -d '/')
            fi
            ln -s $HOME/settings/${file} $HOME/.${file}
        fi
        # for directories
        if [ -d $HOME/settings/${file} ] ; then
            #file=$(echo $file | cut -f 1 -d '/')
            if [ -a $HOME/.${file} ] ; then
                rm -r $HOME/.{file}
            fi
            ln -s $HOME/settings/${file} $HOME/.${file}
        fi
    done
    for file in ${files[@]}; do
        #for files
        if [ -f $HOME/settings/${file} ] ; then
            if [ -a $HOME/${file} ] ; then
                rm $HOME/${file}
            fi
            ln -s $HOME/settings/${file} $HOME/${file}
        fi
        # for directories
        if [ -d $HOME/settings/${file} ] ; then
            if [ -a $HOME/${file} ] ; then
                rm -r $HOME/${file}
            fi
            ln -s $HOME/settings/${file} $HOME/${file}
        fi
    done
}

## add repositories, as needed
#add-repo () {
#    echo "alpha feature! not tested! it can kill you, your mother and your cat!"
#    echo "do you still want to run this script? [y/N]"
#    read reply
#    if [ ${reply} != 'y' !! ${reply} != 'Y' ]
#        then
#            echo "you made the better choice, brother!"
#            exit 2
#    echo "Adding required repositories..."
#    for repo in ${repos[@]}; do
#        tmp=`grep '^deb' ${repo}|tail -n 1|awk {'print $2'}`
#        echo repo: $tmp
#        dir="/etc/apt/sources.list.d/*"
#        if $( grep -v '${tmp}' ${dir} )
#            then
#                echo "Adding \"${repo}\" repository"
#                sudo cp ${repo} /etc/apt/sources.list.d/
#        fi
#    done
#    for repo in ${reposdeb[@]}; do
#        if [ ! $(grep -r ${repo} /etc/apt/sources.list*) ]
#            then
#                echo "Adding \"${repo}\" repository"
#                sudo add-apt-repository --yes ${repo}
#        fi
#    done
#}

## install the required packages, as needed
install () {
    echo "Updating repository information..."
    sudo apt-get -q update
    echo "Installing packages..."
    package=$(echo ${packages[@]} | tr '\n' ' ')
    sudo apt-get install -y ${package}
}

while getopts ":a" opt; do
  case $opt in
    a)
      #ADDREPO=1
      echo "The add-repo function is broken. Going on..."
      ;;
    *)
      echo "Unrecognised option: -$OPTARG."
      echo "Valid options are:"
      echo " -a         Add repositories"
      exit 1
      ;;
  esac
done

files
#if (ADDREPO==1); then add-repo ; fi
install
personal

exit 0
